for что in ["элемент", "множество"]:
    for где in ["элемент", "множество"]:
        for регитр in ["важен", "не важен"]:
            for результат in ["содержит", "не содержит"]:
                print(f"{что} - {где}, регистр {регитр}, результат - {результат}")