from setuptools import setup
setup(
    name="polinu_tools", # имя модуля, которое будет использоваться при установке в будущем
    version="0.2", #версия модуля. При каждом обновлении(новой отрпавке) надо версию увеличивать
    description="Мои инструменты", #описание. Можно не использовать
    packages=["polinu_tools"], # список с названием папок, которые нужно залить
    author_email="ruhliadapolina@gmail.com", # почта автора пакета
    zip_safe=False, # пароль
    # install_requires=[], список названий модулей, которые нужны для корректной работы этого модуля
)